==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/Junit.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Implements JUnit-based testing.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.805Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Junit")
public class Junit extends io.github.cdklabs.projen.Component {

    protected Junit(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Junit(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Junit(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.JunitOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Junit}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Junit> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.JunitOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.java.JunitOptions.Builder();
        }

        /**
         * (experimental) Java pom.
         * <p>
         * @return {@code this}
         * @param pom Java pom. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pom(final io.github.cdklabs.projen.java.Pom pom) {
            this.options.pom(pom);
            return this;
        }

        /**
         * (experimental) Java package for test sample.
         * <p>
         * Default: "org.acme"
         * <p>
         * @return {@code this}
         * @param sampleJavaPackage Java package for test sample. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sampleJavaPackage(final java.lang.String sampleJavaPackage) {
            this.options.sampleJavaPackage(sampleJavaPackage);
            return this;
        }

        /**
         * (experimental) Junit version.
         * <p>
         * Default: "5.7.0"
         * <p>
         * @return {@code this}
         * @param version Junit version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.java.Junit}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Junit build() {
            return new io.github.cdklabs.projen.java.Junit(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/Junit.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Implements JUnit-based testing.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.490Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Junit")
public class Junit extends io.github.cdklabs.projen.Component {

    protected Junit(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Junit(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Junit(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.JunitOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Junit}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Junit> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.JunitOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.java.JunitOptions.Builder();
        }

        /**
         * (experimental) Java pom.
         * <p>
         * @return {@code this}
         * @param pom Java pom. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pom(final io.github.cdklabs.projen.java.Pom pom) {
            this.options.pom(pom);
            return this;
        }

        /**
         * (experimental) Java package for test sample.
         * <p>
         * Default: "org.acme"
         * <p>
         * @return {@code this}
         * @param sampleJavaPackage Java package for test sample. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sampleJavaPackage(final java.lang.String sampleJavaPackage) {
            this.options.sampleJavaPackage(sampleJavaPackage);
            return this;
        }

        /**
         * (experimental) Junit version.
         * <p>
         * Default: "5.7.0"
         * <p>
         * @return {@code this}
         * @param version Junit version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.java.Junit}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Junit build() {
            return new io.github.cdklabs.projen.java.Junit(
                this.project,
                this.options.build()
            );
        }
    }
}
